@@ -30,7 +30,6 @@
 #include "eel-lib-self-check-functions.h"
 #include "eel-enumeration.h"
 #include "eel-glib-extensions.h"
-#include "eel-string-list.h"
 #include "eel-string.h"
 #include <gconf/gconf-client.h>
 #include <gconf/gconf.h>
@@ -44,8 +43,7 @@ typedef enum {
 	PREFERENCE_BOOLEAN = 1,
 	PREFERENCE_INTEGER,
 	PREFERENCE_STRING,
-	PREFERENCE_STRING_LIST,
-	PREFERENCE_STRING_GLIST
+	PREFERENCE_STRING_ARRAY
 } PreferenceType;
 
 /*
@@ -95,7 +93,7 @@ preferences_gconf_value_get_int (const GConfValue *value)
 	if (value == NULL) {
 		return 0;
 	}
-	g_return_val_if_fail (value->type == GCONF_VALUE_INT, 0);
+	g_assert (value->type == GCONF_VALUE_INT);
 	return gconf_value_get_int (value);
 }
 
@@ -105,7 +103,7 @@ preferences_gconf_value_get_bool (const GConfValue *value)
 	if (value == NULL) {
 		return FALSE;
 	}
-	g_return_val_if_fail (value->type == GCONF_VALUE_BOOL, FALSE);
+	g_assert (value->type == GCONF_VALUE_BOOL);
 	return gconf_value_get_bool (value);
 }
 
@@ -115,32 +113,39 @@ preferences_gconf_value_get_string (const GConfValue *value)
 	if (value == NULL) {
 		return g_strdup ("");
 	}
-	g_return_val_if_fail (value->type == GCONF_VALUE_STRING, g_strdup (""));
+	g_assert (value->type == GCONF_VALUE_STRING);
 	return g_strdup (gconf_value_get_string (value));
 }
 
-static EelStringList *
-preferences_gconf_value_get_string_list (const GConfValue *value)
+static char **
+preferences_gconf_value_get_string_array (const GConfValue *value)
 {
-	GSList *slist;
-	EelStringList *result;
+	GSList *slist, *l;
+	GPtrArray *result;
 
 	if (value == NULL) {
-		return eel_string_list_new (TRUE);
+		return NULL;
 	}
-	g_return_val_if_fail (value->type == GCONF_VALUE_LIST, eel_string_list_new (TRUE));
-	g_return_val_if_fail (gconf_value_get_list_type (value) == GCONF_VALUE_STRING, eel_string_list_new (TRUE));
+
+	g_assert (value->type == GCONF_VALUE_LIST);
+	g_assert (gconf_value_get_list_type (value) == GCONF_VALUE_STRING);
 
 	slist = eel_gconf_value_get_string_list (value);
-	result = eel_string_list_new_from_g_slist (slist, TRUE);
-	eel_g_slist_free_deep (slist);
- 	return result;
+
+	result = g_ptr_array_new ();
+	for (l = slist; l != NULL; l = l->next) {
+		g_ptr_array_add (result, l->data);
+	}
+	g_slist_free (slist);
+	g_ptr_array_add (result, NULL);
+
+ 	return (char **) g_ptr_array_free (result, FALSE);
 }
 
 static const char *
 preferences_peek_storage_path (void)
 {
-	g_return_val_if_fail (storage_path != NULL, NULL);
+	g_assert (storage_path != NULL);
 
 	return storage_path;
 }
@@ -148,7 +153,7 @@ preferences_peek_storage_path (void)
 static void
 preferences_set_storage_path (const char *new_storage_path)
 {
-	g_return_if_fail (eel_strlen (new_storage_path) > 0);
+	g_assert (eel_strlen (new_storage_path) > 0);
 
 	/* Make sure the path is indeed different */
 	if (eel_str_is_equal (new_storage_path, storage_path)) {
@@ -181,8 +186,8 @@ preferences_get_value (const char *name)
 	char *key;
 	PreferencesEntry *entry;
 	
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (preferences_is_initialized (), NULL);
+	g_assert (name != NULL);
+	g_assert (preferences_is_initialized ());
 
 	key = preferences_key_make (name);
 	result = eel_gconf_get_value (key);
@@ -203,7 +208,7 @@ preferences_get_value (const char *name)
 static gboolean
 preferences_preference_is_gconf_key (const char *name)
 {
-	g_return_val_if_fail (name != NULL, FALSE);
+	g_assert (name != NULL);
 	
 	if (eel_str_has_prefix (name, "/")) {
 		return FALSE;
@@ -215,7 +220,7 @@ preferences_preference_is_gconf_key (const char *name)
 static char *
 preferences_key_make (const char *name)
 {
-	g_return_val_if_fail (name != NULL, NULL);
+	g_assert (name != NULL);
 	
 	if (!preferences_preference_is_gconf_key (name)) {
 		return g_strdup (name);
@@ -234,7 +239,7 @@ preferences_get_default_value (const char *name)
 	PreferencesEntry *entry;
 	char *key;
 
-	g_return_val_if_fail (name != NULL, NULL);
+	g_assert (name != NULL);
 
 	key = preferences_key_make (name);
 
@@ -282,8 +287,8 @@ preferences_callback_entry_compare (gconstpointer a,
 gboolean
 eel_preferences_get_is_invisible (const char *name)
 {
-	g_return_val_if_fail (name != NULL, FALSE);
-	g_return_val_if_fail (preferences_is_initialized (), FALSE);
+	g_assert (name != NULL);
+	g_assert (preferences_is_initialized ());
 
 	return preferences_global_table_lookup_or_insert (name)->invisible;
 }
@@ -371,7 +376,7 @@ eel_preferences_get_enum (const char *name)
 	int               ret_val;
 	char             *str_value;
 	GConfValue       *value;
-	EelEnumeration   *enumeration;
+	const EelEnumeration   *enumeration;
 	PreferencesEntry *entry;
 
 	g_return_val_if_fail (name != NULL, 0);
@@ -392,7 +397,6 @@ eel_preferences_get_enum (const char *name)
 	if (value->type == GCONF_VALUE_INT) { /* compatibility path */
 		ret_val = preferences_gconf_value_get_int (value);
 		eel_gconf_value_free (value);
-		eel_enumeration_free (enumeration);
 		return ret_val;
 	}
 
@@ -404,9 +408,8 @@ eel_preferences_get_enum (const char *name)
 		return 0;
 	}
 
-	ret_val = eel_enumeration_get_sub_value (enumeration, str_value);
-	eel_enumeration_free (enumeration);
-	
+	ret_val = eel_enumeration_get_value_for_name (enumeration, str_value);
+
 	g_free (str_value);
 
 	return ret_val;
@@ -417,7 +420,7 @@ eel_preferences_set_enum (const char *name,
 			  int         int_value)
 {
 	const char       *str_value;
-	EelEnumeration   *enumeration;
+	const EelEnumeration   *enumeration;
 	PreferencesEntry *entry;
 
 	g_return_if_fail (name != NULL);
@@ -434,7 +437,7 @@ eel_preferences_set_enum (const char *name,
 		return;
 	}
 
-	str_value = eel_enumeration_get_sub_name (enumeration, int_value);
+	str_value = eel_enumeration_get_name_for_value (enumeration, int_value);
 
 	if (str_value == NULL) {
 		g_warning ("No enum match for '%d'", int_value);
@@ -481,48 +484,63 @@ eel_preferences_get (const char *name)
 }
 
 void
-eel_preferences_set_string_list (const char *name,
-				 const EelStringList *string_list_value)
+eel_preferences_set_string_array (const char  *name,
+				  char       **strv_value)
 {
-	char *key;
 	GSList *slist;
+	int i;
+	char *key;
 
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (preferences_is_initialized ());
 
-	slist = eel_string_list_as_g_slist (string_list_value);
+	slist = NULL;
+	if (strv_value != NULL) {
+		for (i = 0; strv_value[i] != NULL; i++) {
+			slist = g_slist_prepend (slist, strv_value[i]);
+		}
+		slist = g_slist_reverse (slist);
+	}
+
 	key = preferences_key_make (name);
 	eel_gconf_set_string_list (key, slist);
 	g_free (key);
 
-	eel_g_slist_free_deep (slist);
+	g_slist_free (slist);
 }
 
 static gboolean
-string_list_is_valid (const EelStringList *string_list,
-		      const char *enumeration_id)
+string_array_is_valid (char **strv, const char *enumeration_id)
 {
 	guint i;
-	char *nth;
-	gboolean bad;
+	gboolean res;
 
-	g_return_val_if_fail (string_list != NULL, FALSE);
-	g_return_val_if_fail (enumeration_id != NULL, FALSE);
+	g_assert (strv != NULL);
+	g_assert (enumeration_id != NULL);
 
-	bad = FALSE;
-	for (i = 0; i < eel_string_list_get_length (string_list) && !bad; i++) {
-		nth = eel_string_list_nth (string_list, i);
-		bad = !eel_enumeration_id_contains_name (enumeration_id, nth);
-		g_free (nth);
+	res = TRUE;
+	for (i = 0; strv[i] != NULL; i++) {
+		const EelEnumeration *enumeration;
+
+		enumeration = eel_enumeration_lookup (enumeration_id);
+		if (!enumeration) {
+			res = FALSE;
+			break;
+		}
+
+		if (!eel_enumeration_contains_name (enumeration, strv[i])) {
+			res = FALSE;
+			break;
+		}
 	}
 
-	return !bad;
+	return res;
 }
 
-EelStringList *
-eel_preferences_get_string_list (const char *name)
+char **
+eel_preferences_get_string_array (const char *name)
 {
- 	EelStringList *result;
+ 	char **result;
 	GConfValue *value;
 	PreferencesEntry *entry;
 	GConfValue *default_value;
@@ -531,9 +549,9 @@ eel_preferences_get_string_list (const char *name)
 	g_return_val_if_fail (preferences_is_initialized (), NULL);
 
 	value = preferences_get_value (name);
-	result = preferences_gconf_value_get_string_list (value);
+	result = preferences_gconf_value_get_string_array (value);
 	eel_gconf_value_free (value);
-	
+
 	entry = preferences_global_table_lookup_or_insert (name);
 	g_assert (entry != NULL);
 
@@ -543,47 +561,22 @@ eel_preferences_get_string_list (const char *name)
 	}
 
 	/* Do a sanity check on the validity of the values */
-	if (string_list_is_valid (result, entry->enumeration_id)) {
+	if (string_array_is_valid (result, entry->enumeration_id)) {
 		return result;
 	}
 
 	/* Forget the bad value and use the default instead */
-	eel_string_list_free (result);
+	g_strfreev (result);
 
 	default_value = preferences_get_default_value (name);
 	if (default_value) {		
-		result = preferences_gconf_value_get_string_list (default_value);
+		result = preferences_gconf_value_get_string_array (default_value);
 		gconf_value_free (default_value);
 	}
 
 	return result;
 }
 
-GList *
-eel_preferences_get_string_glist (const char *name)
-{
-	EelStringList *string_list;
-	GList *ret;
-	
-	string_list = eel_preferences_get_string_list (name);
-	ret = eel_string_list_as_g_list (string_list);
-	eel_string_list_free (string_list);
-
-	return ret;
-}
-
-void           
-eel_preferences_set_string_glist (const char *name,
-				  const GList *string_list_value)
-{
-	EelStringList *string_list;
-	
-	string_list = eel_string_list_new_from_g_list (string_list_value,
-						       TRUE);
-	eel_preferences_set_string_list (name, string_list);
-	eel_string_list_free (string_list);
-}
-
 void
 eel_preferences_unset (const char *name)
 {
@@ -629,7 +622,7 @@ preferences_callback_entry_invoke_function (gpointer data,
 {
 	PreferencesCallbackEntry *callback_entry;
 	
-	g_return_if_fail (data != NULL);
+	g_assert (data != NULL);
 	
 	callback_entry = data;
 
@@ -639,7 +632,7 @@ preferences_callback_entry_invoke_function (gpointer data,
 static void
 preferences_entry_invoke_callbacks (PreferencesEntry *entry)
 {
-	g_return_if_fail (entry != NULL);
+	g_assert (entry != NULL);
 
 	/* Update the auto storage preferences */
 	if (entry->auto_storage_list != NULL) {
@@ -660,8 +653,8 @@ update_auto_string (gpointer data, gpointer callback_data)
 	char **storage;
 	const char *value;
 
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (callback_data != NULL);
+	g_assert (data != NULL);
+	g_assert (callback_data != NULL);
 
 	storage = (char **)data;
 	value = (const char *)callback_data;
@@ -671,41 +664,25 @@ update_auto_string (gpointer data, gpointer callback_data)
 }
 
 static void
-update_auto_string_list (gpointer data, gpointer callback_data)
+update_auto_string_array (gpointer data, gpointer callback_data)
 {
-	EelStringList **storage;
-	const EelStringList *value;
+	char ***storage;
+	char **value;
 	
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (callback_data != NULL);
+	g_assert (data != NULL);
+	g_assert (callback_data != NULL);
 
-	storage = (EelStringList **)data;
-	value = (const EelStringList *)callback_data;
-	
-	eel_string_list_free (*storage);
-	*(EelStringList **)storage = eel_string_list_copy (value);
-}
+	storage = (char ***)data;
+	value = (char **)callback_data;
 
-static void
-update_auto_string_glist (gpointer data, gpointer callback_data)
-{
-	GList **storage;
-	GList *value;
-	
-	g_return_if_fail (data != NULL);
-	g_return_if_fail (callback_data != NULL);
-
-	storage = (GList **)data;
-	value = (GList *)callback_data;
-	
-	eel_g_list_free_deep (*storage);
-	*(GList **)storage = eel_g_str_list_copy (value);
+	g_strfreev (*storage);
+	*(char ***)storage = value ? g_strdupv (value) : NULL;
 }
 
 static void
 update_auto_integer_or_boolean (gpointer data, gpointer callback_data)
 {
-	g_return_if_fail (data != NULL);
+	g_assert (data != NULL);
 
 	*(int *)data = GPOINTER_TO_INT (callback_data);
 }
@@ -714,8 +691,7 @@ static void
 preferences_entry_update_auto_storage (PreferencesEntry *entry)
 {
 	char *new_string_value;
-	EelStringList *new_string_list_value;
-	GList *new_string_glist_value;
+	char **new_string_array_value;
 	int new_int_value;
 	gboolean new_boolean_value;
 
@@ -734,19 +710,12 @@ preferences_entry_update_auto_storage (PreferencesEntry *entry)
 			g_free (new_string_value);
 		}
 		break;
-	case PREFERENCE_STRING_LIST:
-		new_string_list_value = eel_preferences_get_string_list (entry->name);
+	case PREFERENCE_STRING_ARRAY:
+		new_string_array_value = eel_preferences_get_string_array (entry->name);
 		g_list_foreach (entry->auto_storage_list,
-				update_auto_string_list,
-				new_string_list_value);
-		eel_string_list_free (new_string_list_value);
-		break;
-	case PREFERENCE_STRING_GLIST:
-		new_string_glist_value = eel_preferences_get_string_glist (entry->name);
-		g_list_foreach (entry->auto_storage_list,
-				update_auto_string_glist,
-				new_string_glist_value);
-		eel_g_list_free_deep (new_string_glist_value);
+				update_auto_string_array,
+				new_string_array_value);
+		g_strfreev (new_string_array_value);
 		break;
 	case PREFERENCE_INTEGER:
 		new_int_value = eel_preferences_get_integer (entry->name);
@@ -771,9 +740,9 @@ preferences_something_changed_notice (GConfClient *client,
 				      GConfEntry *entry, 
 				      gpointer notice_data)
 {
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (entry->key != NULL);
-	g_return_if_fail (notice_data != NULL);
+	g_assert (entry != NULL);
+	g_assert (entry->key != NULL);
+	g_assert (notice_data != NULL);
 
 	preferences_entry_invoke_callbacks (notice_data);
 }
@@ -792,7 +761,7 @@ preferences_entry_ensure_gconf_connection (PreferencesEntry *entry)
 		return;
 	}
 		
-	g_return_if_fail (entry->name != NULL);
+	g_assert (entry->name != NULL);
 
 	key = preferences_key_make (entry->name);
 
@@ -801,7 +770,7 @@ preferences_entry_ensure_gconf_connection (PreferencesEntry *entry)
 								 entry);
 	g_free (key);
 
-	g_return_if_fail (entry->gconf_connection_id != EEL_GCONF_UNDEFINED_CONNECTION);
+	g_assert (entry->gconf_connection_id != EEL_GCONF_UNDEFINED_CONNECTION);
 }
 
 /**
@@ -821,8 +790,8 @@ preferences_entry_add_callback (PreferencesEntry *entry,
 	PreferencesCallbackEntry *callback_entry;
 	GList *l;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (callback != NULL);
+	g_assert (entry != NULL);
+	g_assert (callback != NULL);
 
 	callback_entry = g_new0 (PreferencesCallbackEntry, 1);
 	callback_entry->callback = callback;
@@ -852,9 +821,9 @@ preferences_entry_add_auto_storage (PreferencesEntry *entry,
 				    gpointer storage,
 				    PreferenceType type)
 {
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (storage != NULL);
-	g_return_if_fail (entry->type == 0 || entry->type == type);
+	g_assert (entry != NULL);
+	g_assert (storage != NULL);
+	g_assert (entry->type == 0 || entry->type == type);
 	if (g_list_find (entry->auto_storage_list, storage) != NULL) {
 		g_warning ("Trying to add an auto storage for %s that already exists.", entry->name);
 		return;
@@ -899,8 +868,8 @@ preferences_entry_remove_callback (PreferencesEntry *entry,
 	PreferencesCallbackEntry cb_entry;
 	GList *l;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (callback != NULL);
+	g_assert (entry != NULL);
+	g_assert (callback != NULL);
 
 	cb_entry.callback = callback;
 	cb_entry.callback_data = callback_data;
@@ -932,16 +901,16 @@ preferences_entry_remove_auto_storage (PreferencesEntry *entry,
 	const GList *node;
 	gpointer storage_in_entry;
 
-	g_return_if_fail (entry != NULL);
-	g_return_if_fail (storage != NULL);
-	g_return_if_fail (entry->auto_storage_list != NULL);
+	g_assert (entry != NULL);
+	g_assert (storage != NULL);
+	g_assert (entry->auto_storage_list != NULL);
 	
 	new_list = g_list_copy (entry->auto_storage_list);
 	
 	for (node = new_list; node != NULL; node = node->next) {
 		storage_in_entry = node->data;
 		
-		g_return_if_fail (storage_in_entry != NULL);
+		g_assert (storage_in_entry != NULL);
 		
 		if (storage_in_entry == storage) {
 			entry->auto_storage_list = g_list_remove (entry->auto_storage_list, 
@@ -951,8 +920,8 @@ preferences_entry_remove_auto_storage (PreferencesEntry *entry,
 			case PREFERENCE_STRING:
 				update_auto_string (storage, NULL);
 				break;
-			case PREFERENCE_STRING_LIST:
-				update_auto_string_list (storage, NULL);
+			case PREFERENCE_STRING_ARRAY:
+				update_auto_string_array (storage, NULL);
 				break;
 			case PREFERENCE_BOOLEAN:
 			case PREFERENCE_INTEGER:
@@ -978,7 +947,7 @@ preferences_entry_remove_auto_storage (PreferencesEntry *entry,
 static void
 preferences_callback_entry_free (PreferencesCallbackEntry *callback_entry)
 {
-	g_return_if_fail (callback_entry != NULL);
+	g_assert (callback_entry != NULL);
 
 	callback_entry->callback = NULL;
 	callback_entry->callback_data = NULL;
@@ -998,7 +967,7 @@ static void
 preferences_callback_entry_free_func (gpointer	data,
 				      gpointer	callback_data)
 {
-	g_return_if_fail (data != NULL);
+	g_assert (data != NULL);
 	
 	preferences_callback_entry_free (data);
 }
@@ -1012,7 +981,7 @@ preferences_callback_entry_free_func (gpointer	data,
 static void
 preferences_entry_free (PreferencesEntry *entry)
 {
-	g_return_if_fail (entry != NULL);
+	g_assert (entry != NULL);
 
 	eel_gconf_notification_remove (entry->gconf_connection_id);
 	entry->gconf_connection_id = EEL_GCONF_UNDEFINED_CONNECTION;
@@ -1096,8 +1065,8 @@ preferences_global_table_get_global (void)
 static PreferencesEntry *
 preferences_global_table_lookup (const char *name)
 {
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (preferences_global_table_get_global () != NULL, NULL);
+	g_assert (name != NULL);
+	g_assert (preferences_global_table_get_global () != NULL);
 	
 	return g_hash_table_lookup (preferences_global_table_get_global (), name);
 }
@@ -1107,16 +1076,16 @@ preferences_global_table_insert (const char *name)
 {
 	PreferencesEntry *entry;
 
-	g_return_val_if_fail (name != NULL, NULL);
-	g_return_val_if_fail (preferences_global_table_get_global () != NULL, NULL);
-	g_return_val_if_fail (preferences_global_table_lookup (name) == NULL, NULL);
+	g_assert (name != NULL);
+	g_assert (preferences_global_table_get_global () != NULL);
+	g_assert (preferences_global_table_lookup (name) == NULL);
 	
 	entry = g_new0 (PreferencesEntry, 1);
 	entry->name = g_strdup (name);
 
 	g_hash_table_insert (preferences_global_table_get_global (), entry->name, entry);
 
-	g_return_val_if_fail (entry == preferences_global_table_lookup (name), NULL);
+	g_assert (entry == preferences_global_table_lookup (name));
 
 	return entry;
 }
@@ -1126,7 +1095,7 @@ preferences_global_table_lookup_or_insert (const char *name)
 {
 	PreferencesEntry *entry;
 
-	g_return_val_if_fail (name != NULL, NULL);
+	g_assert (name != NULL);
 	
 	entry = preferences_global_table_lookup (name);
 
@@ -1179,11 +1148,11 @@ eel_preferences_add_auto_string (const char *name,
 }
 
 void
-eel_preferences_add_auto_string_list (const char *name,
-				      const EelStringList **storage)
+eel_preferences_add_auto_string_array (const char   *name,
+				       char       ***storage)
 {
 	PreferencesEntry *entry;
-	EelStringList *value;
+	char **value;
 
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (storage != NULL);
@@ -1192,32 +1161,11 @@ eel_preferences_add_auto_string_list (const char *name,
 	entry = preferences_global_table_lookup_or_insert (name);
 	g_assert (entry != NULL);
 
-	preferences_entry_add_auto_storage (entry, storage, PREFERENCE_STRING_LIST);
+	preferences_entry_add_auto_storage (entry, storage, PREFERENCE_STRING_ARRAY);
 
-	value = eel_preferences_get_string_list (entry->name);
-	update_auto_string_list (storage, value);
-	eel_string_list_free (value);
-}
-
-void
-eel_preferences_add_auto_string_glist (const char *name,
-				       const GList **storage)
-{
-	PreferencesEntry *entry;
-	GList *value;
-
-	g_return_if_fail (name != NULL);
-	g_return_if_fail (storage != NULL);
-	g_return_if_fail (preferences_is_initialized ());
-
-	entry = preferences_global_table_lookup_or_insert (name);
-	g_assert (entry != NULL);
-
-	preferences_entry_add_auto_storage (entry, storage, PREFERENCE_STRING_GLIST);
-
-	value = eel_preferences_get_string_glist (entry->name);
-	update_auto_string_glist (storage, value);
-	eel_g_list_free_deep (value);
+	value = eel_preferences_get_string_array (entry->name);
+	update_auto_string_array (storage, value);
+	g_strfreev (value);
 }
 
 void
@@ -1302,8 +1250,8 @@ eel_preferences_remove_auto_string (const char *name,
 }
 
 void
-eel_preferences_remove_auto_string_list (const char *name,
-					 const EelStringList **storage)
+eel_preferences_remove_auto_string_array (const char *name,
+					  char ***storage)
 {
 	PreferencesEntry *entry;
 
@@ -1498,8 +1446,8 @@ preferences_set_emergency_fallback_stealing_value (const char *name,
 {
 	PreferencesEntry *entry;
 
-	g_return_if_fail (name != NULL);
-	g_return_if_fail (preferences_is_initialized ());
+	g_assert (name != NULL);
+	g_assert (preferences_is_initialized ());
 
 	entry = preferences_global_table_lookup_or_insert (name);
 	g_assert (entry != NULL);
@@ -1555,34 +1503,32 @@ eel_preferences_set_emergency_fallback_boolean (const char *name,
 	preferences_set_emergency_fallback_stealing_value (name, gconf_value);
 }
 
-static void
-listify_strings_foreach (const char *string,
-			 gpointer callback_data)
-{
-	GSList **listp = callback_data;
-	GConfValue *value;
-
-	value = gconf_value_new (GCONF_VALUE_STRING);
-	gconf_value_set_string (value, string);
-	
-	*listp = g_slist_prepend (*listp, value);
-}
 
 void
-eel_preferences_set_emergency_fallback_string_list (const char    *name,
-						    EelStringList *value)
+eel_preferences_set_emergency_fallback_string_array (const char  *name,
+						     char       **value)
 {
 	GConfValue *gconf_value;
 	GSList *list;
+	int i;
 
 	g_return_if_fail (name != NULL);
 	g_return_if_fail (value != NULL);
-	
-	gconf_value = gconf_value_new (GCONF_VALUE_LIST);
 
+	gconf_value = gconf_value_new (GCONF_VALUE_LIST);
 	gconf_value_set_list_type (gconf_value, GCONF_VALUE_STRING);
+
 	list = NULL;
-	eel_string_list_for_each (value, listify_strings_foreach, &list);
+	for (i = 0; value[i] != NULL; ++i)
+	{
+		GConfValue *v;
+
+		v = gconf_value_new (GCONF_VALUE_STRING);
+		gconf_value_set_string (v, value[i]);
+
+		list = g_slist_prepend (list, v);
+	}
+
 	gconf_value_set_list_nocopy (gconf_value, g_slist_reverse (list));
 
 	preferences_set_emergency_fallback_stealing_value (name, gconf_value);
